.. Bedrock Server Manager Database documentation file

Database
========

.. autoclass:: bedrock_server_manager.db.database.Database
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

   .. automethod:: __init__
